@@ -66,7 +66,7 @@ main::action_version (std::ostream& stream)
   stream << fmt
 	 << _("Written by Roger Leigh") << '\n' << '\n'
     // TRANSLATORS: '(C)' is a copyright symbol and '-' is an en-dash.
-	 << _("Copyright (C) 2004-2010 Roger Leigh") << '\n'
+	 << _("Copyright (C) 2004-2011 Roger Leigh") << '\n'
 	 << _("This is free software; see the source for copying conditions.  There is NO\n"
 	      "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n")
 	 << '\n'
@@ -106,7 +106,7 @@ main::run (int   argc,
       this->program_options->parse(argc, argv);
 
 #ifdef SBUILD_DEBUG
-      sbuild::debug_log_level = sbuild::DEBUG_CRITICAL;
+      sbuild::debug_level = sbuild::DEBUG_CRITICAL;
 #endif
 
       if (this->use_syslog)
