@@ -137,6 +137,9 @@ void
 chroot_config::add (std::string const& chroot_namespace,
 		    std::string const& location)
 {
+  /// @todo Remove and require explicit use of add_config_file or
+  /// add_config_directory; the caller should be aware which is
+  /// required.
   if (stat(location).is_directory())
     add_config_directory(chroot_namespace, location);
   else
@@ -149,6 +152,10 @@ chroot_config::add_config_file (std::string const& chroot_namespace,
 {
   log_debug(DEBUG_NOTICE) << "Loading config file: " << file << endl;
 
+  // Note adding a file skips filename validity checks performed by
+  // add_config_directory; the caller is assumed to have verified that
+  // the file is valid to load.
+
   load_data(chroot_namespace, file);
 }
 
@@ -167,11 +174,7 @@ chroot_config::add_config_directory (std::string const& chroot_namespace,
        dirent != end_iter;
        ++dirent)
     {
-#if !defined(BOOST_FILESYSTEM_VERSION) || BOOST_FILESYSTEM_VERSION == 2
       std::string name(dirent->leaf());
-#else
-      std::string name(dirent->path().filename().string());
-#endif
 
       // Skip common directories.
       if (name == "." || name == "..")
@@ -227,24 +230,6 @@ chroot_config::add (std::string const& chroot_namespace,
 	    this->aliases.insert(std::make_pair(session_alias, fullname));
 	}
 
-      // If a source chroot, add -source compatibility alias.
-      if (chroot_namespace == "source")
-	{
-	  std::string source_alias = std::string("chroot") +
-	    namespace_separator + chroot->get_name() + "-source";
-	  if (this->aliases.find(source_alias) == this->aliases.end())
-	    this->aliases.insert(std::make_pair(source_alias, fullname));
-	}
-
-      // If a session chroot, add compatibility alias.
-      if (chroot_namespace == "session")
-	{
-	  std::string session_alias = std::string("chroot") +
-	    namespace_separator + chroot->get_name();
-	  if (this->aliases.find(session_alias) == this->aliases.end())
-	    this->aliases.insert(std::make_pair(session_alias, fullname));
-	}
-
       // Set up aliases.
       string_list const& aliases = chroot->get_aliases();
       for (string_list::const_iterator pos = aliases.begin();
