@@ -39,8 +39,7 @@ using std::endl;
 using namespace sbuild;
 
 chroot_facet_session::chroot_facet_session ():
-  chroot_facet(),
-  original_chroot_name()
+  chroot_facet()
 {
 }
 
@@ -68,29 +67,13 @@ chroot_facet_session::get_name () const
   return name;
 }
 
-std::string const&
-chroot_facet_session::get_original_name () const
-{
-  return this->original_chroot_name;
-}
-
-void
-chroot_facet_session::set_original_name (std::string const& name)
-{
-  this->original_chroot_name = name;
-}
-
 void
 chroot_facet_session::setup_env (chroot const& chroot,
-				 environment&  env) const
+				     environment&  env) const
 {
-  // Add original name to environment, but only if set (otherwise
-  // defaults to session ID).
-  if (!get_original_name().empty())
-    env.add("CHROOT_NAME", get_original_name());
 }
 
-sbuild::chroot::session_flags
+chroot::session_flags
 chroot_facet_session::get_session_flags (chroot const& chroot) const
 {
   return chroot::SESSION_NOFLAGS;
@@ -100,8 +83,6 @@ void
 chroot_facet_session::get_details (chroot const&  chroot,
 				   format_detail& detail) const
 {
-  if (!get_original_name().empty())
-    detail.add(_("Original Chroot Name"), get_original_name());
   if (!chroot.get_name().empty())
     detail.add(_("Session ID"), chroot.get_name());
 }
@@ -110,9 +91,6 @@ void
 chroot_facet_session::get_keyfile (chroot const& chroot,
 				   keyfile&      keyfile) const
 {
-  keyfile::set_object_value(*this, &chroot_facet_session::get_original_name,
-			    keyfile, chroot.get_name(),
-			    "original-name");
 }
 
 void
@@ -131,36 +109,30 @@ chroot_facet_session::set_keyfile (chroot&        chroot,
   keyfile::get_object_value(*this, nullmethod,
 			    keyfile, chroot.get_name(),
 			    "active",
-			    keyfile::PRIORITY_DEPRECATED);
+			    keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("active");
 
   keyfile::get_object_list_value(*this, nullvmethod,
 				 keyfile, chroot.get_name(),
 				 "source-users",
-				 keyfile::PRIORITY_DEPRECATED);
+				 keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("source-users");
 
   keyfile::get_object_list_value(*this, nullvmethod,
 				 keyfile, chroot.get_name(),
 				 "source-groups",
-				 keyfile::PRIORITY_DEPRECATED);
+				 keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("source-groups");
 
   keyfile::get_object_list_value(*this, nullvmethod,
 				 keyfile, chroot.get_name(),
 				 "source-root-users",
-				 keyfile::PRIORITY_DEPRECATED);
+				 keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("source-root-users");
 
   keyfile::get_object_list_value(*this, nullvmethod,
 				 keyfile, chroot.get_name(),
 				 "source-root-groups",
-				 keyfile::PRIORITY_DEPRECATED);
+				 keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("source-root-groups");
-
-  keyfile::get_object_value(*this, &chroot_facet_session::set_original_name,
-			    keyfile, chroot.get_name(),
-			    "original-name",
-			    keyfile::PRIORITY_OPTIONAL);
-  used_keys.push_back("original-name");
 }
