@@ -104,7 +104,6 @@ error<sbuild::chroot::error_code>::error_strings
 sbuild::chroot::chroot ():
   name(),
   description(),
-  priority(0),
   users(),
   groups(),
   root_users(),
@@ -127,7 +126,6 @@ sbuild::chroot::chroot ():
 sbuild::chroot::chroot (const chroot& rhs):
   name(rhs.name),
   description(rhs.description),
-  priority(rhs.priority),
   users(rhs.users),
   groups(rhs.groups),
   root_users(rhs.root_users),
@@ -250,18 +248,6 @@ sbuild::chroot::set_mount_location (std::string const& location)
   this->mount_location = location;
 }
 
-unsigned int
-sbuild::chroot::get_priority () const
-{
-  return this->priority;
-}
-
-void
-sbuild::chroot::set_priority (unsigned int priority)
-{
-  this->priority = priority;
-}
-
 string_list const&
 sbuild::chroot::get_users () const
 {
@@ -416,14 +402,14 @@ sbuild::chroot::set_command_prefix (string_list const& command_prefix)
   this->command_prefix = command_prefix;
 }
 
-sbuild::chroot::verbosity
-sbuild::chroot::get_verbosity () const
+chroot::verbosity
+chroot::get_verbosity () const
 {
   return this->message_verbosity;
 }
 
 const char *
-sbuild::chroot::get_verbosity_string () const
+chroot::get_verbosity_string () const
 {
   const char *verbosity = 0;
 
@@ -450,13 +436,13 @@ sbuild::chroot::get_verbosity_string () const
 }
 
 void
-sbuild::chroot::set_verbosity (chroot::verbosity verbosity)
+chroot::set_verbosity (chroot::verbosity verbosity)
 {
   this->message_verbosity = verbosity;
 }
 
 void
-sbuild::chroot::set_verbosity (std::string const& verbosity)
+chroot::set_verbosity (std::string const& verbosity)
 {
   if (verbosity == "quiet")
     this->message_verbosity = VERBOSITY_QUIET;
@@ -502,7 +488,7 @@ sbuild::chroot::setup_env (chroot const& chroot,
 {
   env.add("CHROOT_TYPE", chroot.get_chroot_type());
   env.add("CHROOT_NAME", chroot.get_name());
-  env.add("SESSION_ID", chroot.get_name());
+  //  env.add("CHROOT_SESSION_NAME", chroot.get_name());
   env.add("CHROOT_DESCRIPTION", chroot.get_description());
   env.add("CHROOT_MOUNT_LOCATION", chroot.get_mount_location());
   env.add("CHROOT_PATH", chroot.get_path());
@@ -613,7 +599,6 @@ sbuild::chroot::get_details (chroot const&  chroot,
   detail
     .add(_("Description"), chroot.get_description())
     .add(_("Type"), chroot.get_chroot_type())
-    .add(_("Priority"), chroot.get_priority())
     .add(_("Message Verbosity"), chroot.get_verbosity_string())
     .add(_("Users"), chroot.get_users())
     .add(_("Groups"), chroot.get_groups())
@@ -692,10 +677,6 @@ sbuild::chroot::get_keyfile (chroot const& chroot,
 			    keyfile, chroot.get_name(),
 			    "script-config");
 
-  keyfile::set_object_value(chroot, &chroot::get_priority,
-			    keyfile, chroot.get_name(),
-			    "priority");
-
   keyfile::set_object_list_value(chroot, &chroot::get_aliases,
 				 keyfile, chroot.get_name(),
 				 "aliases");
@@ -782,7 +763,7 @@ sbuild::chroot::set_keyfile (chroot&        chroot,
   keyfile::get_object_value(chroot, nullmethod,
 			    keyfile, chroot.get_name(),
 			    "active",
-			    keyfile::PRIORITY_DEPRECATED);
+			    keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("active");
 
   // Setup scripts are run depending on the chroot type in use, and is
@@ -791,7 +772,7 @@ sbuild::chroot::set_keyfile (chroot&        chroot,
   keyfile::get_object_value(chroot, nullmethod,
 			    keyfile, chroot.get_name(),
 			    "run-setup-scripts",
-			    keyfile::PRIORITY_DEPRECATED);
+			    keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("run-setup-scripts");
 
   // Exec scripts have been removed, so these two calls do nothing
@@ -804,7 +785,7 @@ sbuild::chroot::set_keyfile (chroot&        chroot,
   keyfile::get_object_value(chroot, nullmethod,
 			    keyfile, chroot.get_name(),
 			    "run-exec-scripts",
-			    keyfile::PRIORITY_DEPRECATED);
+			    keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("run-exec-scripts");
 
   keyfile::get_object_value(chroot, &chroot::set_script_config,
@@ -813,12 +794,12 @@ sbuild::chroot::set_keyfile (chroot&        chroot,
 			    keyfile::PRIORITY_OPTIONAL);
   used_keys.push_back("script-config");
 
-  keyfile::get_object_value(chroot, &chroot::set_priority,
+  keyfile::get_object_value(chroot, nullmethod,
 			    keyfile, chroot.get_name(),
 			    "priority",
 			    session ?
 			    keyfile::PRIORITY_OPTIONAL :
-			    keyfile::PRIORITY_DEPRECATED);
+			    keyfile::PRIORITY_OBSOLETE);
   used_keys.push_back("priority");
 
   keyfile::get_object_list_value(chroot, &chroot::set_aliases,
