@@ -124,6 +124,65 @@ namespace
       emap(session::USER_SWITCH,    N_("(%1%->%2%): User switching is not permitted")),
     };
 
+  /**
+   * Check group membership.
+   *
+   * @param group the group to check for.
+   * @returns true if the user is a member of group, otherwise false.
+   */
+  bool
+  is_group_member (std::string const& groupname)
+  {
+    errno = 0;
+    sbuild::group grp(groupname);
+    if (!grp)
+      {
+	if (errno == 0)
+	  {
+	    session::error e(groupname, session::GROUP_UNKNOWN);
+	    log_exception_warning(e);
+	  }
+	else
+	  {
+	    session::error e(groupname, session::GROUP_UNKNOWN, strerror(errno));
+	    log_exception_warning(e);
+	  }
+	return false;
+      }
+
+    bool group_member = false;
+    if (grp.gr_gid == getgid())
+      {
+	group_member = true;
+      }
+    else
+      {
+	int supp_group_count = getgroups(0, 0);
+	if (supp_group_count < 0)
+	  throw session::error(session::GROUP_GET_SUPC, strerror(errno));
+	if (supp_group_count > 0)
+	  {
+	    gid_t *supp_groups = new gid_t[supp_group_count];
+	    assert (supp_groups);
+	    if (getgroups(supp_group_count, supp_groups) < 1)
+	      {
+		// Free supp_groups before throwing to avoid leak.
+		delete[] supp_groups;
+		throw session::error(session::GROUP_GET_SUP, strerror(errno));
+	      }
+
+	    for (int i = 0; i < supp_group_count; ++i)
+	      {
+		if (grp.gr_gid == supp_groups[i])
+		  group_member = true;
+	      }
+	    delete[] supp_groups;
+	  }
+      }
+
+    return group_member;
+  }
+
   volatile bool sighup_called = false;
   volatile bool sigint_called = false;
   volatile bool sigterm_called = false;
@@ -350,65 +409,6 @@ session::get_child_status () const
   return this->child_status;
 }
 
-/**
- * Check group membership.
- *
- * @param group the group to check for.
- * @returns true if the user is a member of group, otherwise false.
- */
-bool
-session::is_group_member (std::string const& groupname) const
-{
-  errno = 0;
-  sbuild::group grp(groupname);
-  if (!grp)
-    {
-      if (errno == 0)
-	{
-	  session::error e(groupname, session::GROUP_UNKNOWN);
-	  log_exception_warning(e);
-	}
-      else
-	{
-	  session::error e(groupname, session::GROUP_UNKNOWN, strerror(errno));
-	  log_exception_warning(e);
-	}
-      return false;
-    }
-
-  bool group_member = false;
-  if (grp.gr_gid == getgid())
-    {
-      group_member = true;
-    }
-  else
-    {
-      int supp_group_count = getgroups(0, 0);
-      if (supp_group_count < 0)
-	throw session::error(session::GROUP_GET_SUPC, strerror(errno));
-      if (supp_group_count > 0)
-	{
-	  gid_t *supp_groups = new gid_t[supp_group_count];
-	  assert (supp_groups);
-	  if (getgroups(supp_group_count, supp_groups) < 1)
-	    {
-	      // Free supp_groups before throwing to avoid leak.
-	      delete[] supp_groups;
-	      throw session::error(session::GROUP_GET_SUP, strerror(errno));
-	    }
-
-	  for (int i = 0; i < supp_group_count; ++i)
-	    {
-	      if (grp.gr_gid == supp_groups[i])
-		group_member = true;
-	    }
-	  delete[] supp_groups;
-	}
-    }
-
-  return group_member;
-}
-
 void
 session::get_chroot_membership (chroot::ptr const& chroot,
 				bool&              in_users,
@@ -1050,7 +1050,6 @@ session::setup_chroot (sbuild::chroot::ptr&       session_chroot,
   env.add("AUTH_HOME", this->authstat->get_home());
   env.add("AUTH_SHELL", this->authstat->get_shell());
 
-  env.add("AUTH_VERBOSITY", session_chroot->get_verbosity_string());
   env.add("VERBOSE", session_chroot->get_verbosity_string());
   env.add("MOUNT_DIR", SCHROOT_MOUNT_DIR);
   env.add("LIBEXEC_DIR", SCHROOT_LIBEXEC_DIR);
@@ -1058,6 +1057,7 @@ session::setup_chroot (sbuild::chroot::ptr&       session_chroot,
   env.add("DATA_DIR", SCHROOT_DATA_DIR);
   env.add("SETUP_DATA_DIR", SCHROOT_SETUP_DATA_DIR);
   env.add("PID", getpid());
+  env.add("SESSION_ID", session_chroot->get_name());
   env.add("HOST", SBUILD_HOST);
   env.add("HOST_OS", SBUILD_HOST_OS);
   env.add("HOST_VENDOR", SBUILD_HOST_VENDOR);
@@ -1254,12 +1254,6 @@ session::run_child (sbuild::chroot::ptr& session_chroot)
   env.add("SCHROOT_UID", this->authstat->get_ruid());
   env.add("SCHROOT_GID", this->authstat->get_rgid());
   // Add session ID.
-  chroot_facet_session::const_ptr psess =
-    session_chroot->get_facet<chroot_facet_session>();
-  if (psess && psess->get_original_name().length())
-    env.add("SCHROOT_CHROOT_NAME", psess->get_original_name());
-  else
-    env.add("SCHROOT_CHROOT_NAME", session_chroot->get_name());
   env.add("SCHROOT_SESSION_ID", session_chroot->get_name());
 
   log_debug(DEBUG_INFO) << "Set environment:\n" << env;
@@ -1275,8 +1269,6 @@ session::run_child (sbuild::chroot::ptr& session_chroot)
       if (!env.get("PATH", path))
 	path.clear();
       file = find_program_in_path(full_command[0], path, "");
-      if (file.empty())
-	file = full_command[0];
     }
   for (string_list::const_iterator pos = command.begin();
        pos != command.end();
