@@ -156,7 +156,6 @@ public:
       (chroot->get_facet<sbuild::chroot_facet_personality>());
     if (pfac)
       pfac->set_persona(sbuild::personality("undefined"));
-    chroot->set_priority(3);
 
     sbuild::chroot_facet_source_clonable::ptr usrc
       (chroot->template get_facet<sbuild::chroot_facet_source_clonable>());
@@ -177,7 +176,6 @@ public:
   void setup_env_chroot (sbuild::environment& env)
   {
     env.add("CHROOT_NAME",           "test-name");
-    env.add("SESSION_ID",            "test-name");
     env.add("CHROOT_DESCRIPTION",    "test-description");
     env.add("CHROOT_SCRIPT_CONFIG",  sbuild::normalname(std::string(SCHROOT_SYSCONF_DIR) + "/default/config"));
   }
@@ -186,7 +184,6 @@ public:
 			     std::string const& group)
   {
     keyfile.set_value(group, "description", "test-description");
-    keyfile.set_value(group, "priority", "3");
     keyfile.set_value(group, "aliases", "test-alias-1,test-alias-2");
     keyfile.set_value(group, "users", "user1,user2");
     keyfile.set_value(group, "root-users", "user3,user4");
@@ -204,7 +201,6 @@ public:
 			      std::string const& group)
   {
     setup_keyfile_chroot(keyfile, group);
-    keyfile.set_value(group, "original-name", "test-name");
     keyfile.set_value(group, "users", "user1");
     keyfile.set_value(group, "root-users", "");
     keyfile.set_value(group, "groups", "");
@@ -402,7 +398,7 @@ public:
 	     ++pos)
 	  {
 	    observed_keyfile.get_value(observed_group, *pos, value);
-	    std::cout << "Additional keys: "
+	    std::cout << "Additional keys: " 
 		      << *pos << "=" << value << std::endl;
 	  }
       }
